.. _rconf-reference-convenience:

Convenience methods
========================================================================

Convenience methods for rconf.

.. autofunction:: rconf.build_loader

.. autofunction:: rconf.install_loader

.. autofunction:: rconf.load

.. autofunction:: rconf.loads

.. autofunction:: rconf.loadc

.. autofunction:: rconf.loadu
